package com.atguigu.spzx.manger.service.impl;

import com.atguigu.exception.BunnyException;
import com.atguigu.exception.EnumException;
import com.atguigu.spzx.manger.mapper.SysUserMapper;
import com.atguigu.spzx.manger.service.SysUserService;
import com.atguigu.spzx.model.dto.system.LoginDto;
import com.atguigu.spzx.model.entity.system.SysUser;
import com.atguigu.spzx.model.vo.system.LoginVo;
import com.atguigu.utils.MD5;
import com.atguigu.utils.StringEmptyUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class SysUserServiceImpl implements SysUserService {
    @Autowired
    StringEmptyUtil stringEmptyUtil;
    @Autowired
    private SysUserMapper sysUserMapper;
    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * * 登录请求实现
     *
     * @param loginDto 登录请求参数
     * @return 登录后结果
     */
    @Override
    public LoginVo login(LoginDto loginDto) {
        String password = loginDto.getPassword();
        String userName = loginDto.getUserName();
        stringEmptyUtil.isEmpty(userName, EnumException.USERNAME_IS_EMPTY);
        stringEmptyUtil.isEmpty(password, EnumException.PASSWORD_IS_EMPTY);

        // 根据username查询用户信息
        SysUser sysUser = sysUserMapper.selectByUsername(userName);
        if (sysUser == null) {
            throw new BunnyException(EnumException.USER_NOT_FOUND);
        }
        String encryptedPassword = MD5.encrypt(password);
        // 比较密码
        if (!encryptedPassword.equals(sysUser.getPassword())) {
            throw new BunnyException(EnumException.PASSWORD_ERROR);
        }
        // 登录成功
        String token = UUID.randomUUID().toString().replaceAll("-", "");
        redisTemplate.opsForValue().set(userName, token, 7, TimeUnit.DAYS);
        // 返回loginVo对象
        return LoginVo.builder().token(token).build();
    }
}
